@@ -94,7 +94,10 @@ function add_virtual_sink() {
         props="sink_properties=device.description=$NAME"
     fi
 
-    pacmd load-module module-null-sink sink_name=svm-virtual-sink "$props"
+    local pipewire_opts="object.linger=1 media.class=Audio/Sink"
+
+    pactl load-module module-null-sink sink_name=svm-${NAME:-virtual-sink} $pipewire_opts "$props" \
+        || pactl load-module module-null-sink sink_name=svm-${NAME:-virtual-sink} "$props"
 }
 
 function toggle_looking_glass() {
@@ -102,7 +105,7 @@ function toggle_looking_glass() {
 }
 
 
-function enable_debuggin() {
+function enable_debugging() {
     local enable="$1"
 
     if [[ $enable == 1 || $enable == true ]]; then
